==> tailbone-corepos-0.1.7.tar.gz: tailbone-corepos-0.1.7/CHANGELOG.md <==

# Changelog
All notable changes to tailbone-corepos will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.1.7] - 2021-11-04
### Changed
- Add views for CORE "Users" and "Suspensions".
- Only show "in use" products by default, in grid.
- Remove unwanted autocomplete view config.
- Add config for PendingCustomerView.
- Show "view in CORE" buttons for profile view.
- Add more views for product origins.
- Expose new CORE member batch feature.

## [0.1.6] - 2021-08-31
### Changed
- Add "view in CORE" button when viewing MemberInfo.

## [0.1.5] - 2021-08-02
### Changed
- Tweak form to make editing CORE product possible.
- Highlight products not in use.
- Expose views for `TableSyncRules`.
- Add web templates to manifest.
- Expose card number filter by default, for `meminfo` grid.

## [0.1.4] - 2021-06-11
### Changed
- Several more updates...mostly a "save point" release.

## [0.1.3] - 2020-09-25
### Changed
- Don't require CORE ID when creating/editing Person.
- Add generic menu link for CORE Office.

## [0.1.2] - 2020-09-16
### Changed
- A ton of updates, mostly a "save point" release.

## [0.1.1] - 2020-02-27
### Changed
- Add support for multiple DB engines, and HouseCoupon views.
- Show proper flags breakdown for products.
- Highlight inactive product flags as 'warning' in grid.
- Add master view for Parameter model.
- Allow CRUD actions by default, for CORE master views.
- Hide some problematic fields for create/edit CORE customer.
- Cleanup various attribute names, per changes in pyCOREPOS.

## [0.1.0] - 2019-07-09
### Changed
- Initial release.

==> tailbone-corepos-0.1.10.tar.gz: tailbone-corepos-0.1.10/CHANGELOG.md <==

# Changelog
All notable changes to tailbone-corepos will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## [0.1.10] - 2022-03-07
### Changed
- Add tailbone provider to declare native and corepos view options.
- Allow download results by default for all CORE views.

## [0.1.9] - 2022-03-02
### Changed
- Show input filename column in CORE member batches grid.
- Include views for PendingProduct model.
- Tweak exposure for some fields.
- Add basic views for CORE user groups.
- Update config defaults for all corepos views.

## [0.1.8] - 2021-11-05
### Changed
- Show member type names for CORE member batch.

## [0.1.7] - 2021-11-04
### Changed
- Add views for CORE "Users" and "Suspensions".
- Only show "in use" products by default, in grid.
- Remove unwanted autocomplete view config.
- Add config for PendingCustomerView.
- Show "view in CORE" buttons for profile view.
- Add more views for product origins.
- Expose new CORE member batch feature.

## [0.1.6] - 2021-08-31
### Changed
- Add "view in CORE" button when viewing MemberInfo.

## [0.1.5] - 2021-08-02
### Changed
- Tweak form to make editing CORE product possible.
- Highlight products not in use.
- Expose views for `TableSyncRules`.
- Add web templates to manifest.
- Expose card number filter by default, for `meminfo` grid.

## [0.1.4] - 2021-06-11
### Changed
- Several more updates...mostly a "save point" release.

## [0.1.3] - 2020-09-25
### Changed
- Don't require CORE ID when creating/editing Person.
- Add generic menu link for CORE Office.

## [0.1.2] - 2020-09-16
### Changed
- A ton of updates, mostly a "save point" release.

## [0.1.1] - 2020-02-27
### Changed
- Add support for multiple DB engines, and HouseCoupon views.
- Show proper flags breakdown for products.
- Highlight inactive product flags as 'warning' in grid.
- Add master view for Parameter model.
- Allow CRUD actions by default, for CORE master views.
- Hide some problematic fields for create/edit CORE customer.
- Cleanup various attribute names, per changes in pyCOREPOS.

## [0.1.0] - 2019-07-09
### Changed
- Initial release.
